@@ -42,38 +42,37 @@ class Calculator:
     >>> c.add(20)
     25.0
     >>> c.reset()
-    0.0
-"""
+    0.0"""
 
     memory: float = 0.0
     number: float
 
     def __init__(self) -> None:
-        """ Initiates class and sets up memory to 0 """
+        """Initiates class and sets up memory to 0"""
         self.memory: float = 0.0
 
     def add(self, number: float) -> float:
-        """ Add a number to the current memory """
+        """Add a number to the current memory"""
         self.memory += number
         return self.memory
 
     def subs(self, number: float) -> float:
-        """ Substract a number from the current memory """
+        """Substract a number from the current memory"""
         self.memory -= number
         return self.memory
 
     def mult(self, number: float) -> float:
-        """ Miltiply a number to the current memory """
+        """Miltiply a number to the current memory"""
         self.memory *= number
         return self.memory
 
     def div(self, number: float) -> float:
-        """ Divide a number to the current memory """
+        """Divide a number to the current memory"""
         self.memory /= number
         return self.memory
 
     def root(self, number: Optional[float] = None) -> float:
-        """ Calculate the root of the current memory """
+        """Calculate the root of the current memory"""
         if number:
             self.memory = math.sqrt(float(number))
             return self.memory
@@ -82,12 +81,12 @@ class Calculator:
         return self.memory
 
     def reset(self) -> float:
-        """ Reset memory to 0 """
+        """Reset memory to 0"""
         self.memory = 0.0
         return self.memory
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     import doctest
-    print(doctest.testmod())
 
+    print(doctest.testmod())
